pub enum VmError {
BadSize {
requested: usize,
unit: usize,
},
SyscallError {
op: &'static str,
err: Errno,
},
InvalidMapping {
base: GuestAddress,
size: u64,
},
}Variants
BadSize
the requested VM’s memory size was not an even number of pages.
SyscallError
one of the several syscalls in operating a VM failed.
this deserves better documentation, but i’m not aware of documentation for KVM ioctl failure modes.
InvalidMapping
base and size are not valid for mapping; either because of over/underflow, or overlaps
with an existing mapping.