pub enum VmCreateError {
TooSmall {
requested: usize,
required: usize,
},
BadSize {
requested: usize,
unit: usize,
},
SyscallError {
op: &'static str,
err: Errno,
},
InvalidMapping {
base: GuestAddress,
size: u64,
},
}Variants
TooSmall
the requested VM was smaller than asmlinator’s minimum allowable size.
BadSize
the requested VM’s memory size was not an even number of pages.
SyscallError
one of the several syscalls in setting up a new VM failed.
this is most likely a permissions error, or /dev/kvm doesn’t exist. otherwise, something
interesting happened!
this deserves better documentation, but i’m not aware of documentation for KVM ioctl failure modes.
InvalidMapping
base and size are not valid for mapping; either because of over/underflow, or overlaps
with an existing mapping.